==> webpdf-wsclient-2.0.2-sources.jar: net/webpdf/wsclient/schema/operation/ThreadActionType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ThreadActionType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ThreadActionType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://schema.webpdf.de/1.0/operation}ActionEventType"&gt;
 *       &lt;attribute name="beadIndex"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="0"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="page" default="1"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="1"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="threadTitle" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="threadIndex"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="0"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ThreadActionType")
public class ThreadActionType
    extends ActionEventType
{

    @XmlAttribute(name = "beadIndex")
    protected Integer beadIndex;
    @XmlAttribute(name = "page")
    protected Integer page;
    @XmlAttribute(name = "threadTitle")
    protected String threadTitle;
    @XmlAttribute(name = "threadIndex")
    protected Integer threadIndex;

    /**
     * Gets the value of the beadIndex property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getBeadIndex() {
        return beadIndex;
    }

    /**
     * Sets the value of the beadIndex property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setBeadIndex(int value) {
        this.beadIndex = value;
    }

    public boolean isSetBeadIndex() {
        return (this.beadIndex!= null);
    }

    public void unsetBeadIndex() {
        this.beadIndex = null;
    }

    /**
     * Gets the value of the page property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getPage() {
        if (page == null) {
            return  1;
        } else {
            return page;
        }
    }

    /**
     * Sets the value of the page property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setPage(int value) {
        this.page = value;
    }

    public boolean isSetPage() {
        return (this.page!= null);
    }

    public void unsetPage() {
        this.page = null;
    }

    /**
     * Gets the value of the threadTitle property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getThreadTitle() {
        return threadTitle;
    }

    /**
     * Sets the value of the threadTitle property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setThreadTitle(String value) {
        this.threadTitle = value;
    }

    public boolean isSetThreadTitle() {
        return (this.threadTitle!= null);
    }

    /**
     * Gets the value of the threadIndex property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getThreadIndex() {
        return threadIndex;
    }

    /**
     * Sets the value of the threadIndex property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setThreadIndex(int value) {
        this.threadIndex = value;
    }

    public boolean isSetThreadIndex() {
        return (this.threadIndex!= null);
    }

    public void unsetThreadIndex() {
        this.threadIndex = null;
    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/ThreadActionType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;When activated, the goToThread action jumps to a specific thread defined in the document.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for ThreadActionType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="ThreadActionType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}ActionEventType">
 *       <attribute name="beadIndex">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}int">
 *             <minInclusive value="0"/>
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="page" default="1">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}int">
 *             <minInclusive value="1"/>
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *       <attribute name="threadTitle" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="threadIndex">
 *         <simpleType>
 *           <restriction base="{http://www.w3.org/2001/XMLSchema}int">
 *             <minInclusive value="0"/>
 *           </restriction>
 *         </simpleType>
 *       </attribute>
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ThreadActionType")
public class ThreadActionType
    extends ActionEventType
{

    @XmlAttribute(name = "beadIndex")
    protected Integer beadIndex;
    @XmlAttribute(name = "page")
    protected Integer page;
    @XmlAttribute(name = "threadTitle")
    protected String threadTitle;
    @XmlAttribute(name = "threadIndex")
    protected Integer threadIndex;

    /**
     * Gets the value of the beadIndex property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getBeadIndex() {
        return beadIndex;
    }

    /**
     * Sets the value of the beadIndex property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setBeadIndex(int value) {
        this.beadIndex = value;
    }

    public boolean isSetBeadIndex() {
        return (this.beadIndex!= null);
    }

    public void unsetBeadIndex() {
        this.beadIndex = null;
    }

    /**
     * Gets the value of the page property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getPage() {
        if (page == null) {
            return  1;
        } else {
            return page;
        }
    }

    /**
     * Sets the value of the page property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setPage(int value) {
        this.page = value;
    }

    public boolean isSetPage() {
        return (this.page!= null);
    }

    public void unsetPage() {
        this.page = null;
    }

    /**
     * Gets the value of the threadTitle property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getThreadTitle() {
        return threadTitle;
    }

    /**
     * Sets the value of the threadTitle property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setThreadTitle(String value) {
        this.threadTitle = value;
    }

    public boolean isSetThreadTitle() {
        return (this.threadTitle!= null);
    }

    /**
     * Gets the value of the threadIndex property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getThreadIndex() {
        return threadIndex;
    }

    /**
     * Sets the value of the threadIndex property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setThreadIndex(int value) {
        this.threadIndex = value;
    }

    public boolean isSetThreadIndex() {
        return (this.threadIndex!= null);
    }

    public void unsetThreadIndex() {
        this.threadIndex = null;
    }

}
